@@ -47,19 +47,76 @@ print.summary.hpaBinary <- function (x, ...)
 #' Plot hpaBinary random errors approximated density
 #' @param x Object of class "hpaBinary"
 #' @param y this parameter currently ignored
-#' @template elipsis_Template
+#' @template elipsis_plot_Template
 plot.hpaBinary <- function (x, y = NULL, ...) 
 {
-  if (length(list(...)) > 0)
-  {
-    warning("Additional arguments passed through ... are ignored.")   
-  }
   if (!is.null(y))
   {
     warning("Note that y parameter currently ignored.")   
   }
+  
+  # Load data from the model
+  pol_coefficients <- as.numeric(unlist(x["pol_coefficients"]))
+  pol_degrees <- as.numeric(unlist(x["pol_degrees"]))
 
-  return(plot_hpaBinary(x))
+  mean <- as.numeric(x["mean"])
+  sd <- as.numeric(x["sd"])
+  
+  # Adjust precision
+  errors_exp <- as.numeric(x["errors_exp"])
+  errors_var <- as.numeric(x["errors_var"])
+
+  plot_min <- errors_exp - 3.8 * sqrt(errors_var);
+  plot_max <- errors_exp + 3.8 * sqrt(errors_var);
+  
+  n <- 10000;
+  
+  precise <- (plot_max - plot_min) / n;
+  
+  x_vec <- plot_min + cumsum(rep(precise, n))
+
+  den <- dhpa(x = x_vec,
+              pol_coefficients = pol_coefficients, 
+              pol_degrees = pol_degrees,
+              mean = mean, sd = sd)
+  
+  den_min = min(den)
+  den_max = max(den)
+  
+  # Plot the result
+  
+  # prepare the arguments
+  plot_args <- list(...)
+  plot_args_names <- names(plot_args)
+  if(!("xlim" %in% plot_args_names))
+  {
+    plot_args$xlim <- c(plot_min, plot_max)
+  }
+  if(!("type" %in% plot_args_names))
+  {
+    plot_args$type <- "l"
+  }
+  if(!("lwd" %in% plot_args_names))
+  {
+    plot_args$lwd <- 3
+  }
+  if(!("main" %in% plot_args_names))
+  {
+    plot_args$main <- "Random Errors Density Approximation Plot"
+  }
+  if(!("xlab" %in% plot_args_names))
+  {
+    plot_args$xlab <- "value"
+  }
+  if(!("ylab" %in% plot_args_names))
+  {
+    plot_args$ylab <- "density"
+  }
+  plot_args$x = x_vec
+  plot_args$y = den
+  
+  # make the plot
+  do.call(plot, plot_args)
 }
 
 ###
@@ -103,3 +160,29 @@ print.hpaBinary <- function (x, ...)
   cat("---\n")
   cat("Please, use summary() function to get additional information\n")
 }
+
+#' Extract coefficients from hpaBinary object
+#' @param object Object of class "hpaBinary"
+#' @template elipsis_Template
+coef.hpaBinary <- function (object, ...)
+{
+  if (length(list(...)) > 0)
+  {
+    warning("Additional arguments passed through ... are ignored.")   
+  }
+  
+  return(object$x1)
+}
+
+#' Extract covariance matrix from hpaBinary object
+#' @param object Object of class "hpaBinary"
+#' @template elipsis_Template
+vcov.hpaBinary <- function (object, ...)
+{
+  if (length(list(...)) > 0)
+  {
+    warning("Additional arguments passed through ... are ignored.")   
+  }
+  
+  return(object$cov_mat)
+}
\ No newline at end of file
